This is unreleased documentation for the main (development) branch of crypto-glue.

Parameters

Struct Parameters 

pub struct Parameters<'a> {
    pub kdf: Kdf<'a>,
    pub encryption: EncryptionScheme<'a>,
}
Password-Based Encryption Scheme 2 parameters as defined in RFC 8018 Appendix A.4.

 PBES2-params ::= SEQUENCE {
      keyDerivationFunc AlgorithmIdentifier {{PBES2-KDFs}},
      encryptionScheme AlgorithmIdentifier {{PBES2-Encs}} }

Fields

kdf: Kdf<'a>

Key derivation function

encryption: EncryptionScheme<'a>

Encryption scheme

Implementations

Source

impl<'a> Parameters<'a>

pub fn pbkdf2_sha256_aes128cbc( pbkdf2_iterations: u32, pbkdf2_salt: &'a [u8], aes_iv: &'a [u8; 16], ) -> Result<Self>

Initialize PBES2 parameters using PBKDF2-SHA256 as the password-based key derivation function and AES-128-CBC as the symmetric cipher.

pub fn pbkdf2_sha256_aes256cbc( pbkdf2_iterations: u32, pbkdf2_salt: &'a [u8], aes_iv: &'a [u8; 16], ) -> Result<Self>

Initialize PBES2 parameters using PBKDF2-SHA256 as the password-based key derivation function and AES-256-CBC as the symmetric cipher.

pub fn scrypt_aes128cbc( params: Params, salt: &'a [u8], aes_iv: &'a [u8; 16], ) -> Result<Self>

Initialize PBES2 parameters using scrypt as the password-based key derivation function and AES-128-CBC as the symmetric cipher.

For more information on scrypt parameters, see documentation for the scrypt::Params struct.

pub fn scrypt_aes256cbc( params: Params, salt: &'a [u8], aes_iv: &'a [u8; 16], ) -> Result<Self>

Initialize PBES2 parameters using scrypt as the password-based key derivation function and AES-256-CBC as the symmetric cipher.

For more information on scrypt parameters, see documentation for the scrypt::Params struct.

When in doubt, use Default::default() as the scrypt::Params. This also avoids the need to import the type from the scrypt crate.

pub fn decrypt( &self, password: impl AsRef<[u8]>, ciphertext: &[u8], ) -> Result<Vec<u8>>

Attempt to decrypt the given ciphertext, allocating and returning a byte vector containing the plaintext.

pub fn decrypt_in_place<'b>( &self, password: impl AsRef<[u8]>, buffer: &'b mut [u8], ) -> Result<&'b [u8]>

Attempt to decrypt the given ciphertext in-place using a key derived from the provided password and this scheme’s parameters.

Returns an error if the algorithm specified in this scheme’s parameters is unsupported, or if the ciphertext is malformed (e.g. not a multiple of a block mode’s padding)

pub fn encrypt( &self, password: impl AsRef<[u8]>, plaintext: &[u8], ) -> Result<Vec<u8>>

Encrypt the given plaintext, allocating and returning a vector containing the ciphertext.

pub fn encrypt_in_place<'b>( &self, password: impl AsRef<[u8]>, buffer: &'b mut [u8], pos: usize, ) -> Result<&'b [u8]>

Encrypt the given plaintext in-place using a key derived from the provided password and this scheme’s parameters, writing the ciphertext into the same buffer.