pub struct Parameters<'a> {
pub kdf: Kdf<'a>,
pub encryption: EncryptionScheme<'a>,
}Expand description
Password-Based Encryption Scheme 2 parameters as defined in RFC 8018 Appendix A.4.
PBES2-params ::= SEQUENCE {
keyDerivationFunc AlgorithmIdentifier {{PBES2-KDFs}},
encryptionScheme AlgorithmIdentifier {{PBES2-Encs}} }Fields
kdf: Kdf<'a>Key derivation function
encryption: EncryptionScheme<'a>Encryption scheme
Implementations
Sourceimpl<'a> Parameters<'a>
impl<'a> Parameters<'a>
Sourcepub fn pbkdf2_sha256_aes128cbc(
pbkdf2_iterations: u32,
pbkdf2_salt: &'a [u8],
aes_iv: &'a [u8; 16],
) -> Result<Self>
pub fn pbkdf2_sha256_aes128cbc( pbkdf2_iterations: u32, pbkdf2_salt: &'a [u8], aes_iv: &'a [u8; 16], ) -> Result<Self>
Initialize PBES2 parameters using PBKDF2-SHA256 as the password-based key derivation function and AES-128-CBC as the symmetric cipher.
Sourcepub fn pbkdf2_sha256_aes256cbc(
pbkdf2_iterations: u32,
pbkdf2_salt: &'a [u8],
aes_iv: &'a [u8; 16],
) -> Result<Self>
pub fn pbkdf2_sha256_aes256cbc( pbkdf2_iterations: u32, pbkdf2_salt: &'a [u8], aes_iv: &'a [u8; 16], ) -> Result<Self>
Initialize PBES2 parameters using PBKDF2-SHA256 as the password-based key derivation function and AES-256-CBC as the symmetric cipher.
Sourcepub fn scrypt_aes128cbc(
params: Params,
salt: &'a [u8],
aes_iv: &'a [u8; 16],
) -> Result<Self>
pub fn scrypt_aes128cbc( params: Params, salt: &'a [u8], aes_iv: &'a [u8; 16], ) -> Result<Self>
Initialize PBES2 parameters using scrypt as the password-based key derivation function and AES-128-CBC as the symmetric cipher.
For more information on scrypt parameters, see documentation for the
scrypt::Params struct.
Sourcepub fn scrypt_aes256cbc(
params: Params,
salt: &'a [u8],
aes_iv: &'a [u8; 16],
) -> Result<Self>
pub fn scrypt_aes256cbc( params: Params, salt: &'a [u8], aes_iv: &'a [u8; 16], ) -> Result<Self>
Initialize PBES2 parameters using scrypt as the password-based key derivation function and AES-256-CBC as the symmetric cipher.
For more information on scrypt parameters, see documentation for the
scrypt::Params struct.
When in doubt, use Default::default() as the scrypt::Params.
This also avoids the need to import the type from the scrypt crate.
Sourcepub fn decrypt(
&self,
password: impl AsRef<[u8]>,
ciphertext: &[u8],
) -> Result<Vec<u8>>
pub fn decrypt( &self, password: impl AsRef<[u8]>, ciphertext: &[u8], ) -> Result<Vec<u8>>
Attempt to decrypt the given ciphertext, allocating and returning a byte vector containing the plaintext.
Sourcepub fn decrypt_in_place<'b>(
&self,
password: impl AsRef<[u8]>,
buffer: &'b mut [u8],
) -> Result<&'b [u8]>
pub fn decrypt_in_place<'b>( &self, password: impl AsRef<[u8]>, buffer: &'b mut [u8], ) -> Result<&'b [u8]>
Attempt to decrypt the given ciphertext in-place using a key derived from the provided password and this scheme’s parameters.
Returns an error if the algorithm specified in this scheme’s parameters is unsupported, or if the ciphertext is malformed (e.g. not a multiple of a block mode’s padding)