pub struct Pbkdf2Params<'a> {
pub salt: &'a [u8],
pub iteration_count: u32,
pub key_length: Option<u16>,
pub prf: Pbkdf2Prf,
}Expand description
Password-Based Key Derivation Scheme 2 parameters as defined in RFC 8018 Appendix A.2.
PBKDF2-params ::= SEQUENCE {
salt CHOICE {
specified OCTET STRING,
otherSource AlgorithmIdentifier {{PBKDF2-SaltSources}}
},
iterationCount INTEGER (1..MAX),
keyLength INTEGER (1..MAX) OPTIONAL,
prf AlgorithmIdentifier {{PBKDF2-PRFs}} DEFAULT
algid-hmacWithSHA1 }Fields
salt: &'a [u8]PBKDF2 salt
iteration_count: u32PBKDF2 iteration count
key_length: Option<u16>PBKDF2 output length
prf: Pbkdf2PrfPseudo-random function to use with PBKDF2
Implementations
Sourceimpl<'a> Pbkdf2Params<'a>
impl<'a> Pbkdf2Params<'a>
Sourcepub const MAX_ITERATION_COUNT: u32 = 100_000_000
pub const MAX_ITERATION_COUNT: u32 = 100_000_000
Implementation defined maximum iteration count of 100,000,000.
For especially critical keys, or for very powerful systems or systems where user-perceived performance is not critical, an iteration count of 10,000,000 may be appropriate.
See RFC 8018, 4.2 and RFC 8018, A.2
Sourcepub fn hmac_with_sha256(iteration_count: u32, salt: &'a [u8]) -> Result<Self>
pub fn hmac_with_sha256(iteration_count: u32, salt: &'a [u8]) -> Result<Self>
Initialize PBKDF2-SHA256 with the given iteration count and salt